==> haskell-say-0.1.0.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-1QSNimHp1sX7jJPrvLJbIq
key:                  say-0.1.0.1-1QSNimHp1sX7jJPrvLJbIq
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  a9ce208b781871992f875437e62a6253
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/say-0.1.0.1
hs-libraries:         HSsay-0.1.0.1-1QSNimHp1sX7jJPrvLJbIq
depends:
    base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-say-0.1.0.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-10To3LsaTVv42tBw7d061y
key:                  say-0.1.0.1-10To3LsaTVv42tBw7d061y
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  5869d4c8a3fb93ee5a687d3614038b54
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/say-0.1.0.1
hs-libraries:         HSsay-0.1.0.1-10To3LsaTVv42tBw7d061y
depends:
    base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
